@@ -1040,6 +1040,15 @@ class KiwoomOpenApiPlusDispatchFunctions:
 
             >>> KOA_Functions("GetMasterListedStockCntEx", "종목코드(6자리)")
 
+            10. 종목코드로 Market구분 구하기 (2022/3/3 적용)
+            종목코드 입력으로 해당 종목이 어느 시장에 포함되어 있는지 구하는 기능
+            서버와의 통신없이 메모리에 상주하는 값을 사용하므로 횟수제한 등은 없습니다. 사용법은 아래와 같습니다.
+
+            >>> KOA_Functions("GetStockMarketKind", "종목코드6자리")
+
+            리턴값은 문자형으로 아래와 같습니다.
+            "0":코스피, "10":코스닥, "3":ELW, "8":ETF, "4"/"14":뮤추얼펀드, "6"/"16":리츠, "9"/"19":하이일드펀드, "30":제3시장, "60":ETN
+
         Args:
             sFunctionName (str): 함수이름 혹은 기능이름
             sParam (str): 함수 매개변수
